# investigator

# Local setup (for development)

Fine-grained and Application access token needs the following permissions:

Administration: Read-only
Metadata: Read-only will be automatically set when you set Administration
Dependabot Alerts: Read-only
Secret scanning alerts: Read-only
Code scanning alerts: Read-only